@@ -4,7 +4,7 @@ import logging
 from django.core.cache import cache
 from django.core.validators import MinLengthValidator
 from django.db import models
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from .connect import client_connect
 
@@ -468,10 +468,7 @@ def get_next_color():
     color = cache.get('LAST_ASANA_COLOR')
     if color:
         index = COLORS.index(color)
-        if index == len(COLORS) - 1:
-            color = COLORS[0]
-        else:
-            color = COLORS[index + 1]
+        color = COLORS[0] if index == len(COLORS) - 1 else COLORS[index + 1]
     else:
         color = COLORS[0]
     cache.set('LAST_ASANA_COLOR', color)
