@@ -1,23 +1,24 @@
 import json
 from unittest.mock import patch
 
-import django
 from asana.error import ForbiddenError
+import django
 from django.http import Http404
 from django.test import override_settings, TestCase, RequestFactory
-if django.VERSION >= (2, 0, 0):
-    from django.urls import reverse
-else:
-    from django.core.urlresolvers import reverse
 
 from djasana import models, views
 from djasana.tests.fixtures import attachment, project, story, task, user
 from djasana.utils import sign_sha256_hmac
 
+if django.VERSION >= (2, 0, 0):
+    from django.urls import reverse
+else:
+    from django.core.urlresolvers import reverse
 
-@override_settings(ASANA_ACCESS_TOKEN='foo')
-@override_settings(ASANA_WORKSPACE=None)
-@override_settings(ROOT_URLCONF='djasana.urls')
+
+@override_settings(
+    ASANA_ACCESS_TOKEN='foo', ASANA_WORKSPACE=None,
+    DJASANA_WEBHOOK_URL='https://example.com/hooks/', ROOT_URLCONF='djasana.urls')
 class WebhookViewTestCase(TestCase):
 
     @classmethod
@@ -33,12 +34,17 @@ class WebhookViewTestCase(TestCase):
         cls.data = {
             'events': [
                 {
-                  'action': 'changed',
-                  'created_at': '2017-08-21T18:20:37.972Z',
-                  'parent': None,
-                  'resource': 1337,
-                  'type': 'task',
-                  'user': 1123
+                    'action': 'changed',
+                    'created_at': '2017-08-21T18:20:37.972Z',
+                    'parent': None,
+                    'resource': {
+                        'gid': '1337',
+                        'resource_type': 'task',
+                    },
+                    'user': {
+                        'gid': '1123',
+                        'resource_type': 'user',
+                    },
                 },
             ]
         }
@@ -46,7 +52,7 @@ class WebhookViewTestCase(TestCase):
     def _get_mock_response(self, mock_client, data):
         message = json.dumps(data)
         signature = sign_sha256_hmac(self.secret, message)
-        mock_client.access_token().projects.find_by_id.return_value = project()
+        mock_client.access_token().projects.find_by_id.return_value = project(gid='3')
         mock_client.access_token().tasks.find_by_id.return_value = task()
         request = self.factory.post(
             '', content_type='application/json', data=message,
@@ -122,20 +128,23 @@ class WebhookViewTestCase(TestCase):
     def test_valid_request(self, mock_client):
         models.Webhook.objects.create(project=self.project, secret=self.secret)
         task_ = models.Task.objects.create(remote_id=99, name='Old task Name')
-        mock_client.access_token().tasks.find_by_id.return_value = task(id=99)
+        mock_client.access_token().tasks.find_by_id.return_value = task(gid='99')
         mock_client.access_token().attachments.find_by_task.return_value = [attachment()]
         mock_client.access_token().attachments.find_by_id.return_value = attachment()
-        mock_client.access_token().stories.find_by_task.return_value = [story()]
-        mock_client.access_token().stories.find_by_id.return_value = story()
         data = {
             'events': [
                 {
                     'action': 'changed',
                     'created_at': '2017-08-21T18:20:37.972Z',
                     'parent': None,
-                    'resource': 99,
-                    'type': 'task',
-                    'user': 1123
+                    'resource': {
+                        'gid': '99',
+                        'resource_type': 'task',
+                    },
+                    'user': {
+                        'gid': '1123',
+                        'resource_type': 'user',
+                    },
                 },
             ]
         }
@@ -148,10 +157,6 @@ class WebhookViewTestCase(TestCase):
             models.Attachment.objects.get(remote_id=1)
         except models.Attachment.DoesNotExist:
             self.fail('Attachment not created')
-        try:
-            models.Story.objects.get(remote_id=1)
-        except models.Story.DoesNotExist:
-            self.fail('Story not created')
 
     @patch('djasana.connect.Client')
     def test_bad_task_id(self, mock_client):
@@ -175,10 +180,15 @@ class WebhookViewTestCase(TestCase):
                 {
                     'action': 'added',
                     'created_at': '2017-08-21T18:20:37.972Z',
-                    'parent': {'id': 10},
-                    'resource': 1337,
-                    'type': 'task',
-                    'user': 1123
+                    'parent': {'gid': '10'},
+                    'resource': {
+                        'gid': '1337',
+                        'resource_type': 'task',
+                    },
+                    'user': {
+                        'gid': '1123',
+                        'resource_type': 'user',
+                    },
                 },
             ]
         }
@@ -192,15 +202,19 @@ class WebhookViewTestCase(TestCase):
         parent, child = tuple(models.Task.objects.order_by('remote_id'))
         self.assertEqual(parent, child.parent)
 
-    @patch('djasana.connect.Client')
-    def test_task_deleted(self, mock_client):
-        models.Webhook.objects.create(project=self.project, secret=self.secret)
-        task_ = models.Task.objects.create(remote_id=1337, name='Old task Name')
+    @staticmethod
+    def setup_task_for_delete(mock_client):
         mock_client.access_token().tasks.find_by_id.return_value = task()
         mock_client.access_token().attachments.find_by_task.return_value = [attachment()]
         mock_client.access_token().attachments.find_by_id.return_value = attachment()
         mock_client.access_token().stories.find_by_task.return_value = [story()]
         mock_client.access_token().stories.find_by_id.return_value = story()
+
+    @patch('djasana.connect.Client')
+    def test_task_removed(self, mock_client):
+        models.Webhook.objects.create(project=self.project, secret=self.secret)
+        task_ = models.Task.objects.create(remote_id=1337, name='Name')
+        self.setup_task_for_delete(mock_client)
         data = self.data.copy()
         data['events'][0]['action'] = 'removed'
         response = self._get_mock_response(mock_client, data)
@@ -209,18 +223,36 @@ class WebhookViewTestCase(TestCase):
         with self.assertRaises(models.Task.DoesNotExist):
             models.Task.objects.get(pk=task_.pk)
 
+    @patch('djasana.connect.Client')
+    def test_task_deleted(self, mock_client):
+        models.Webhook.objects.create(project=self.project, secret=self.secret)
+        task_ = models.Task.objects.create(remote_id=1337, name='Name')
+        self.setup_task_for_delete(mock_client)
+        data = self.data.copy()
+        data['events'][0]['action'] = 'deleted'
+        response = self._get_mock_response(mock_client, data)
+        self.assertEqual(200, response.status_code)
+        self.assertFalse('x-hook-secret' in response)
+        with self.assertRaises(models.Task.DoesNotExist):
+            models.Task.objects.get(pk=task_.pk)
+
     @patch('djasana.connect.Client')
     def test_project_updated(self, mock_client):
         models.Webhook.objects.create(project=self.project, secret=self.secret)
         data = {
             'events': [
                 {
-                  'action': 'changed',
-                  'created_at': '2017-08-21T18:20:37.972Z',
-                  'parent': None,
-                  'resource': 3,
-                  'type': 'project',
-                  'user': 1123
+                    'action': 'changed',
+                    'created_at': '2017-08-21T18:20:37.972Z',
+                    'parent': None,
+                    'resource': {
+                        'gid': '3',
+                        'resource_type': 'project',
+                    },
+                    'user': {
+                        'gid': '1123',
+                        'resource_type': 'user',
+                    },
                 },
             ]
         }
@@ -239,9 +271,14 @@ class WebhookViewTestCase(TestCase):
                     'action': 'removed',
                     'created_at': '2017-08-21T18:20:37.972Z',
                     'parent': None,
-                    'resource': 3,
-                    'type': 'project',
-                    'user': 1123
+                    'resource': {
+                        'gid': '3',
+                        'resource_type': 'project',
+                    },
+                    'user': {
+                        'gid': '1123',
+                        'resource_type': 'user',
+                    },
                 },
             ]
         }
@@ -261,10 +298,19 @@ class WebhookViewTestCase(TestCase):
                 {
                     'action': 'added',
                     'created_at': '2017-08-21T18:20:37.972Z',
-                    'parent': None,
-                    'resource': 12,
-                    'type': 'story',
-                    'user': 1123
+                    'parent': {
+                        'gid': '1337',
+                        'resource_type': 'task',
+                    },
+                    'resource': {
+                        'gid': '12',
+                        'resource_type': 'story',
+                        'resource_subtype': 'comment_added',
+                    },
+                    'user': {
+                        'gid': '1123',
+                        'resource_type': 'user',
+                    },
                 },
             ]
         }
